Module proxy

Module proxy 

Functions

extract_authorization
Returns the value of the Authorization header, or None.
extract_host
headers_end
Index of the first byte after the header block (i.e. after \r\n\r\n).
is_chunked
parse_content_length
parse_request_line
Try to extract method and path from the first line of an HTTP request.
parse_response_status
Extract the status code from the first line of an HTTP response.
read_http_head
Read from a TCP stream until we have the full HTTP header block. Returns the buffered bytes (headers + any body bytes already received).
write_401
write_404
write_502