Functions
- extract_
authorization - Returns the value of the Authorization header, or None.
- extract_
host - headers_
end - Index of the first byte after the header block (i.e. after \r\n\r\n).
- is_
chunked - parse_
content_ length - parse_
request_ line - Try to extract method and path from the first line of an HTTP request.
- parse_
response_ status - Extract the status code from the first line of an HTTP response.
- read_
http_ head - Read from a TCP stream until we have the full HTTP header block. Returns the buffered bytes (headers + any body bytes already received).
- write_
401 - write_
404 - write_
502